@@ -48,15 +48,14 @@ class Fetcher(GObject.GObject):
     def done(self, local_file_path):
         ...
 
-    @GObject.property(type=bool, default=False)
+    @GObject.Property(type=bool, default=False)
     def running(self):
         return self._run
 
-    @GObject.property(type=GObject.TYPE_DOUBLE)
+    @GObject.Property(type=float)
     def fraction(self):
         return self._fraction
 
-
     def __init__(self, source, dest=None, cbk=None):
         """ download `source` to `dest`
             `source`: uri
@@ -83,7 +82,7 @@ class Fetcher(GObject.GObject):
                 block_size = 8192
                 dwl_size = 0
                 # python in runtime is old :)
-                #while chunk := fsrc.read(block_size):
+                # while chunk := fsrc.read(block_size):
                 chunk = fsrc.read(block_size)
                 while chunk:
                     if not self._run:
@@ -92,12 +91,14 @@ class Fetcher(GObject.GObject):
                     if total_size > 0:
                         dwl_size += block_size
                         self._fraction = min(dwl_size, total_size) / total_size
-                        GLib.idle_add(self.notify,"fraction")
+                        GLib.idle_add(self.notify, "fraction")
                     chunk = fsrc.read(block_size)
         except Exception as e:
             if os.path.exists(dest):
                 os.unlink(dest)
-            import traceback;  traceback.print_exc()
+            import traceback
+            traceback.print_exc()
+
             GLib.idle_add(self.emit, "error", str(e))
         else:
             GLib.idle_add(self._done, dest)
@@ -107,7 +108,9 @@ class Fetcher(GObject.GObject):
             try:
                 self._cbk(self, dest)
             except Exception as e:
-                import traceback;  traceback.print_exc()
+                import traceback
+                traceback.print_exc()
+
                 GLib.idle_add(self.emit, "error", str(e))
                 return
         GLib.idle_add(self.emit, "done", dest)
@@ -115,5 +118,3 @@ class Fetcher(GObject.GObject):
     def cancel(self):
         self._run = False
         self.notify("running")
-
-
