@@ -1,6 +1,6 @@
 # local.py
 #
-# Copyright 2020-2022 Fabio Comuni, et al.
+# Copyright 2020-2024 Fabio Comuni, et al.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,27 +14,32 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+from typing import Optional
 
 import types
 import os
 import json
 import hashlib
-import urllib.request
 import sqlite3
 import importlib.util
 import datetime
 import time
+from gettext import gettext as _
 
 from gi.repository import GLib
-from gi.repository import GObject
 
 from .settings import Settings
 from .fetcher import Fetcher
 from . import remotes
+from . import models
 
 
 # # init and migration machinery
 
+class UnitializedError(Exception):
+    pass
+
+
 class LocalDBDoesNotExistsException(Exception):
     pass
 
@@ -43,10 +48,10 @@ class LocalDBNotOpen(Exception):
     pass
 
 
-dbfile = None
-db = None
-appdir = None
-cachedir = None
+dbfile: Optional[str] = None
+db: Optional[sqlite3.Connection] = None
+appdir: Optional[str] = None
+cachedir: Optional[str] = None
 
 
 def getDb():
@@ -71,6 +76,8 @@ def init(app_id: str):
 def import_migration(filename: str) -> types.ModuleType:
     modulename = os.path.basename(filename).replace(".py", "")
     spec = importlib.util.spec_from_file_location(modulename, filename)
+    if spec is None or spec.loader is None:
+        raise ImportError(f"Unable to import migration {filename}")
     migration = importlib.util.module_from_spec(spec)
     spec.loader.exec_module(migration)
     return migration
@@ -112,7 +119,7 @@ def migrate():
 # event database
 
 
-def openconf(conf, is_online=True):
+def openconf(conf: models.Conference, is_online=True):
     """Open event database for `conf`
 
     conf is a models.Conference
@@ -138,7 +145,7 @@ def openconf(conf, is_online=True):
 def existsdb(url):
     """Check if exists database for `url`"""
     dbhashname = hashlib.md5(url.encode('utf8')).hexdigest()
-    dbfilename = os.path.join(cachedir, dbhashname+".db")
+    dbfilename = os.path.join(cachedir, dbhashname + ".db")
     return os.path.exists(dbfilename)
 
 
@@ -151,7 +158,7 @@ def opendb(url, is_online=True):
     """
     global dbfile, db
     dbhashname = hashlib.md5(url.encode('utf8')).hexdigest()
-    dbfilename = os.path.join(cachedir, dbhashname+".db")
+    dbfilename = os.path.join(cachedir, dbhashname + ".db")
     if not os.path.exists(dbfilename) and not is_online:
         db = None
         raise LocalDBDoesNotExistsException(_("Device disconnected and no cached data available."))
@@ -199,6 +206,8 @@ def close():
 def update_menu() -> Fetcher:
     """Fetch remote menu json"""
     # TODO: what about user entries shadowing entries from giggity?
+    if cachedir is None:
+        raise UnitializedError("cachedir is not defiend, local db not initialized")
     ggcachefile = os.path.join(cachedir, "ggmenu.json")
     url = "https://ggt.gaa.st/menu.json"
     return Fetcher(url, ggcachefile)
@@ -213,7 +222,7 @@ def open_menu(is_online):
     print("menu cache file:", ggcachefile)
 
     need_refresh = not os.path.exists(ggcachefile)
-    need_refresh = need_refresh or ((time.time() -  os.path.getmtime(ggcachefile)) > Settings.instance().get_list_cache())
+    need_refresh = need_refresh or ((time.time() - os.path.getmtime(ggcachefile)) > Settings.instance().get_list_cache())
     if need_refresh and is_online:
         return update_menu()
 
@@ -233,7 +242,7 @@ def get_menu():
     if os.path.exists(userfile):
         with open(userfile, "r") as f:
             schedules += json.load(f)
-    userurls = [ s['url'] for s in schedules ]
+    userurls = [s['url'] for s in schedules]
 
     if os.path.exists(ggcachefile):
         with open(ggcachefile, "r") as f:
@@ -286,11 +295,11 @@ def add_user_menu(url, cbk):
     When ready calls "cbk({..metadata..})"
     """
     # try to not add same event twice:
-    objs = [ e for e in get_menu() if e['url'] == url ]
+    objs = [e for e in get_menu() if e['url'] == url]
     if len(objs) > 0:
         raise MenuItemAlreadyExistsException(_("Event already in list"), objs[0])
 
-    f = opendb(url, True) # I suppose that we are online at this point..
+    f = opendb(url, True)  # I suppose that we are online at this point..
     if f is not None:
         f.connect("done", _add_user_menu_ready, cbk)
     else:
@@ -389,6 +398,7 @@ def get_cache_size():
                     total_size += os.path.getsize(fp)
     return total_size
 
+
 def clear_cache():
     """remove all files in cachedir except currently opened database and json menu files"""
     for dirpath, dirnames, filenames in os.walk(cachedir):
