@@ -1,7 +1,10 @@
 from gi.repository import GObject
 from gi.repository import Gio
 
+
 class NetworkConnectionMonitor(GObject.Object):
+    __gtype_name__ = "ConfyNetworkConnectionMonitor"
+
     def __init__(self):
         super().__init__()
         self._isconnected = False
@@ -13,14 +16,14 @@ class NetworkConnectionMonitor(GObject.Object):
         _ic = self._isconnected
         self._isconnected = self.nm.get_connectivity() == Gio.NetworkConnectivity.FULL
         if (self._isconnected != _ic):
-            #print("NetworkConnectionMonitor.isconnected", self._isconnected)
+            # print("NetworkConnectionMonitor.isconnected", self._isconnected)
             self.notify("isconnected")
 
-    @GObject.Property
+    @GObject.Property(type=bool, default=False)
     def isconnected(self):
         """The system can reach the global netowrk. Bool, read-only"""
-        #print("NetworkConnectionMonitor.isconnected getter:", self._isconnected)
+        # print("NetworkConnectionMonitor.isconnected getter:", self._isconnected)
         return self._isconnected
 
-
-
+    def get_isconnected(self) -> bool:
+        return self._isconnected
