@@ -15,35 +15,15 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from os import path
-import datetime
-import html
-import math
-import re
-
-from dateutil.tz import UTC
-
-from gi.repository import GLib
-from gi.repository import GObject
-from gi.repository import Gio
-from gi.repository import Gdk
-from gi.repository import Gtk
-from gi.repository import GdkPixbuf
-from gi.repository import Adw
-from gi.repository import Graphene
-from gi.repository import Gsk
-
-from ..utils import clean_markup
-
 from .eventeditdialog import EventEditDialog
 from .loaderpage import LoaderPage
-from .pageheaderbar import PageHeaderBar
 from .searchbaroverlay import SearchBarOverlay
-from .sidebar import SideBar
+from .navbar import Navbar
 from .starbutton import StarButton
 from .datepickerrow import DatePickerRow
 from .inputdialog import InputDialog
 from .loadingoverlay import LoadingOverlay
 from .eventactionrow import EventActionRow
 from .weblinkactionrow import WebLinkActionRow, weblinkactionrowactivated
-
+from .author import Author
+from .togglesidebarbutton import ToggleSidebarButton
