@@ -25,16 +25,16 @@ class StarButton(Gtk.Button):
     __gtype_name__ = "ConfyStarButton"
 
     _is_starred = False
+
     @GObject.Property(type=bool, default=True)
     def is_starred(self):
-        return _is_starred
+        return self._is_starred
 
     @is_starred.setter
-    def is_starred(self, v):
+    def is_starred_setter(self, v):
         self._is_starred = v
         self.notify("icon-name")
 
     @GObject.Property(type=str, default="non-starred-symbolic")
     def icon_name(self):
         return "starred-symbolic" if self._is_starred else "non-starred-symbolic"
-
